@@ -8,10 +8,9 @@ import re
 
 import unidecode
 
-from ... import (__homepage__, __project_name__, __version__, constants,
-                 errors, jobs)
-from ...utils import (cached_property, fs, http, image, release, string,
-                      timestamp, video, webdbs)
+from ... import __homepage__, __project_name__, __version__, errors, jobs
+from ...utils import (cached_property, fs, http, image, release, string, video,
+                      webdbs)
 from ..base import TrackerJobsBase
 
 import logging  # isort:skip
@@ -721,12 +720,12 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_directors_cut(self):
-        if 'DC' in self.release_name.edition:
+        if "Director's Cut" in self.release_name.edition:
             return "Director's Cut"
 
     @property
     def release_info_theatrical_cut(self):
-        if 'Theatrical' in self.release_name.edition:
+        if 'Theatrical Cut' in self.release_name.edition:
             return 'Theatrical Cut'
 
     @property
@@ -736,7 +735,7 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_extended_edition(self):
-        if 'Extended' in self.release_name.edition:
+        if 'Extended Cut' in self.release_name.edition:
             return 'Extended Edition'
 
     @property
@@ -751,12 +750,12 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_criterion_edition(self):
-        if 'Criterion' in self.release_name.edition:
+        if 'Criterion Collection' in self.release_name.edition:
             return 'Criterion Edition'
 
     @property
     def release_info_special_edition(self):
-        if 'Special' in self.release_name.edition:
+        if 'Special Edition' in self.release_name.edition:
             return 'Special Edition'
 
     @property
@@ -1094,26 +1093,29 @@ class BbTrackerJobs(TrackerJobsBase):
                     + ', '.join(countries))
 
     async def format_description_runtime(self):
-        def format_runtime(seconds):
-            if seconds > 0:
-                return f'[b]Runtime[/b]: {timestamp.pretty(runtime)}'
+        def format_runtime(minutes):
+            if minutes > 60:
+                hours = minutes // 60
+                minutes = minutes - ((minutes // 60) * 60)
+                if minutes:
+                    return f'{hours}h{minutes}m'
+                else:
+                    return f'{hours}h'
+            else:
+                return f'{minutes}m'
 
-        if self.is_movie_release or self.is_episode_release:
-            runtime = video.duration(self.content_path, default=0)
-            return format_runtime(runtime)
-        elif self.is_season_release:
-            # Get all video files
-            filepaths = fs.file_list(self.content_path, extensions=constants.VIDEO_FILE_EXTENSIONS)
-            if len(filepaths) >= 5:
-                # Ignore first and last episode as they can be significantly longer
-                filepaths = filepaths[1:-1]
-            # Get average from 3 episodes
-            filepaths = filepaths[:3]
-            durations = [video.duration(f, default=0) for f in filepaths]
-            runtime = sum(durations) / len(durations)
-            return format_runtime(runtime)
-        else:
-            return None
+        runtimes = await self.try_webdbs((self.imdb, self.tvmaze), 'runtimes')
+        if len(runtimes) == 1:
+            runtime = tuple(runtimes.values())[0]
+            return f'[b]Runtime[/b]: {format_runtime(runtime)}'
+        elif len(runtimes) > 1:
+            parts = []
+            for cut, minutes in runtimes.items():
+                part = f'{format_runtime(minutes)}'
+                if cut != 'default':
+                    part += f' ({cut})'
+                parts.append(part)
+            return f'[b]Runtimes[/b]: {", ".join(parts)}'
 
     @staticmethod
     def _format_person(person):
