@@ -7,7 +7,7 @@ import re
 import urllib
 
 from ... import errors
-from ...utils import argtypes, html, http
+from ...utils import html, http
 from ..base import TrackerBase
 from .config import BbTrackerConfig
 from .jobs import BbTrackerJobs
@@ -20,47 +20,6 @@ class BbTracker(TrackerBase):
     name = 'bb'
     label = 'bB'
 
-    argument_definitions = {
-        ('--anime', '--an'): {
-            'help': 'Upload as anime (ignored for movies)',
-            'action': 'store_true',
-        },
-        ('--poster-file',): {
-            'help': 'Path or URL to poster image',
-        },
-        ('--screenshots', '--ss'): {
-            'help': ('How many screenshots to make '
-                     f'(min={BbTrackerConfig.defaults["screenshots"].min}, '
-                     f'max={BbTrackerConfig.defaults["screenshots"].max})'),
-            'type': argtypes.number_of_screenshots(BbTrackerConfig),
-        },
-        ('--title', '-t'): {
-            'group': 'single-job',
-            'help': 'Only generate title',
-            'action': 'store_true',
-        },
-        ('--description', '-d'): {
-            'group': 'single-job',
-            'help': 'Only generate description',
-            'action': 'store_true',
-        },
-        ('--poster', '-p'): {
-            'group': 'single-job',
-            'help': 'Only generate poster URL',
-            'action': 'store_true',
-        },
-        ('--release-info', '-i'): {
-            'group': 'single-job',
-            'help': 'Only generate release info',
-            'action': 'store_true',
-        },
-        ('--tags', '-g'): {
-            'group': 'single-job',
-            'help': 'Only generate tags',
-            'action': 'store_true',
-        },
-    }
-
     TrackerConfig = BbTrackerConfig
     TrackerJobs = BbTrackerJobs
 
