@@ -24,6 +24,23 @@ class DummyTrackerConfig(base.TrackerConfigBase):
         'image_host' : 'dummy',
     }
 
+    argument_definitions = {
+        ('--skip-category', '-C'): {
+            'help': 'Do not ask for category',
+            'action': 'store_true',
+        },
+        ('--screenshots', '--ss'): {
+            'help': 'How many screenshots to make',
+            'type': int,
+            'default': 3,
+        },
+        ('--delay', '-d'): {
+            'help': 'Number of seconds login, upload and logout take each',
+            'type': float,
+            'default': 1.0,
+        },
+    }
+
 
 class DummyTrackerJobs(base.TrackerJobsBase):
     @cached_property
@@ -44,12 +61,13 @@ class DummyTrackerJobs(base.TrackerJobsBase):
     def category_job(self):
         if not self.options['skip_category']:
 
-            def select_release_category(release_name):
-                _log.debug('Setting type: %r', release_name.type)
-                if release_name.type:
-                    self.category_job.focused = release_name.type
+            def select_release_category(_):
+                user_approved_release_name = self.release_name
+                _log.debug('Setting type: %r', user_approved_release_name.type)
+                if user_approved_release_name.type:
+                    self.category_job.focused = user_approved_release_name.type
 
-            self.release_name_job.signal.register('release_name', select_release_category)
+            self.release_name_job.signal.register('output', select_release_category)
 
             choices = [(str(t).capitalize(), t) for t in ReleaseType if t]
             return jobs.dialog.ChoiceJob(
@@ -64,23 +82,6 @@ class DummyTracker(base.TrackerBase):
     name = 'dummy'
     label = 'DuMmY'
 
-    argument_definitions = {
-        ('--skip-category', '-C'): {
-            'help': 'Do not ask for category',
-            'action': 'store_true',
-        },
-        ('--screenshots', '-s'): {
-            'help': 'How many screenshots to make',
-            'type': int,
-            'default': 3,
-        },
-        ('--delay', '-d'): {
-            'help': 'Number of seconds login, upload and logout take each',
-            'type': float,
-            'default': 1.0,
-        },
-    }
-
     TrackerJobs = DummyTrackerJobs
     TrackerConfig = DummyTrackerConfig
 
