@@ -129,12 +129,15 @@ class CommandBase(abc.ABC):
     :attr:`argument_definitions`.
     """
 
+    subcommand_name = 'PLEASE_GIVE_THIS_SUBCOMMAND_A_PROPER_METAVAR'
+    """Reference to expected subcommand in help"""
+
     description = ''
     """
     Extended description
 
-    The class docstring is the main description. Use this attribute to generate
-    text programmatically.
+    The class docstring is the main description. Use this class attribute to
+    generate text programmatically.
     """
 
     @classmethod
@@ -165,7 +168,16 @@ class CommandBase(abc.ABC):
 
         # Add subcommands
         if cls.subcommands:
-            subparsers = parser.add_subparsers()
+            subparsers = parser.add_subparsers(
+                metavar=cls.subcommand_name,
+                help='Valid values: ' + ', '.join(sorted(cls.subcommands)),
+            )
+            # FIXME: When Python 3.6 is not supported anymore, `required=True`
+            #        should be passed to add_subparsers() instead.
+            #        https://docs.python.org/3/library/argparse.html#argparse.ArgumentParser.add_subparsers
+            #        https://bugs.python.org/issue26510
+            #        https://bugs.python.org/issue9253
+            subparsers.required = True
             for subcmd, args in cls.subcommands.items():
                 subparser = subparsers.add_parser(subcmd, formatter_class=_MyHelpFormatter)
                 subparser.set_defaults(subcommand=subcmd)
@@ -266,6 +278,26 @@ class CommandBase(abc.ABC):
         """Config file options as :class:`~.configfiles.ConfigFiles` object"""
         return self._config
 
+    def get_options(self, config_name, config_section):
+        """
+        Combine section in config file with CLI arguments
+
+        CLI arguments take precedence unless their value is `None`.
+
+        :param str config_name: Config file name with out the "INI" extension
+        :param str config_section: Name of a section in the config file
+
+        :return: `dict`
+        """
+        config = self.config[config_name][config_section]
+        args = vars(self.args)
+        options = {}
+        options.update(config)
+        for k, v in args.items():
+            if v is not None:
+                options[k] = v
+        return options
+
     @property
     def home_directory(self):
         """
